@@ -40,6 +40,7 @@ extern const char* get_documents_path(char* file);
 
 int __saved = 0;
 
+bool accel_move;
 PcsxConfig Config;
 R3000Acpu *psxCpu;
 psxRegisters* psxRegs;
@@ -129,12 +130,14 @@ int main(int argc, char *argv[])
 	displayFrameInfo = 0;
 #endif
 bool fullscreen=false;
+accel_move=false;
 	for (i=1; i<argc; i++) {
 		if (!strcmp(argv[i], "-runcd")) runcd = 1;
 		else if (!strcmp(argv[i], "-psxout")) Config.PsxOut = 1;
+		else if (!strcmp(argv[i], "-accel")) accel_move=true;
 		else if (!strcmp(argv[i], "-load")) loadst = argv[++i];
 		else if (!strcmp(argv[i], "-nosound")) iSoundMuted = 1;
-		else if (!strcmp(argv[i], "-fullscreen")) fullscreen = 1;
+		else if (!strcmp(argv[i], "-fullscreen")) fullscreen = true;
 #ifndef PEOPS_GPU
 		else if (!strcmp(argv[i], "-showfps")) displayFrameInfo = 1;
 #endif
@@ -197,6 +200,7 @@ bool fullscreen=false;
 							"\t-abbeyfix\tEnabling Abbeyfix\n"
 							"\t-fullscreen\tEnabling scaling\n"
 							"\t-autoskip\tEnable autoskiping\n"
+							"\t-accel\tEnable accelometer\n"
 							"\tFILE\t\tCdRom file\n\n"
 							"bugtracker at http://code.google.com/p/psx4m/issues/list\n"
 							"donation wmz:Z111042450361"));
@@ -261,7 +265,8 @@ printf ("Started\n");
 		"Cycle Multiplier         %d\n"
 		"Abe's Oddysee Fix        %s\n"
 		"Sound                    %s\n"
-		"Fullscreen               %s\n",
+		"Fullscreen               %s\n"
+		"Accelometer              %s\n",
 		file,
 
 		(displayFrameInfo == false ? "OFF" : "ON"),
@@ -280,8 +285,8 @@ printf ("Started\n");
 		(enableAbbeyHack == false ? "OFF" : "ON"),
 		
 		(iSoundMuted == 0 ? "ON" : "OFF"),
-		(fullscreen == true ? "ON" : "OFF")
-
+		(fullscreen == true ? "ON" : "OFF"),
+		(accel_move==true ? "ON":"OFF")
 	);
 	#endif
 
