@@ -119,9 +119,6 @@ inline  fixed xSqrt(fixed _uVal)
 ///////////////////////////////////////////////////////////////////////////
 inline int Log2(int _a)
 {
-/* 
-// WTF???, speed hack
-
   const unsigned int b[] = {0x2, 0xC, 0xF0, 0xFF00, 0xFFFF0000};
   const unsigned int S[] = {1, 2, 4, 8, 16};
   unsigned int c = 0; // result of log2(v) will go here
@@ -130,16 +127,7 @@ inline int Log2(int _a)
   if (_a & b[2]) { _a >>= S[2]; c |= S[2];  }
   if (_a & b[1]) { _a >>= S[1]; c |= S[1];  }
   if (_a & b[0]) { _a >>= S[0]; c |= S[0];  }
-  */
-  unsigned int c = 0;
-  switch(_a){
-  case 0x2:c=1;break;
-  case 0xC:c=2;break;
-  case 0xF0:c=4;break;
-  case 0xFF00:c=8;break;
-  case 0xFFFF0000:c=16;break;  
-  default:c=0;break;
-  }
+
   return c;
 }
 
