@@ -43,7 +43,7 @@ void ReadConfig(void)                                  // read config (linux fil
  bChangeRes=FALSE;
  bWindowMode=TRUE;
  iUseScanLines=0;
- bFullScreen=TRUE;
+ bFullScreen=FALSE;
  bFullVRam=FALSE;
  iFilterType=0;
  bAdvancedBlend=FALSE;
