@@ -144,6 +144,11 @@ void GetExtInfos(void)
 
  bGLExt=FALSE;                                         // default: no extensions
  bGLFastMovie=FALSE;
+/*
+ BOOL bPacked=FALSE;                                   // default: no packed pixel support
+
+ bGLExt=FALSE;                                         // default: no extensions
+ bGLFastMovie=FALSE;
 
  if(strstr((char *)glGetString(GL_EXTENSIONS),         // packed pixels available?
     "GL_EXT_packed_pixels"))                          
@@ -157,11 +162,11 @@ void GetExtInfos(void)
    bGLFastMovie=TRUE;                                  // -> ok
    bGLExt=TRUE;
   }
-
+*/
  iClampType=GL_CLAMP_TO_EDGE ;
 
  glColorTableEXTEx=(PFNGLCOLORTABLEEXT)NULL;           // init ogl palette func pointer
-
+/*
  if(iGPUHeight!=1024 &&                                // no pal textures in ZN mode (height=1024)! 
     strstr((char *)glGetString(GL_EXTENSIONS),         // otherwise: check ogl support
     "GL_EXT_paletted_texture"))
@@ -172,7 +177,9 @@ void GetExtInfos(void)
 
    if(glColorTableEXTEx==NULL) iUsePalTextures=0;      // -> ha, cheater... no func, no support
   }
- else iUsePalTextures=0;
+ else 
+ */
+ iUsePalTextures=0;
 }
 
 ////////////////////////////////////////////////////////////////////////
@@ -446,6 +453,7 @@ void CreateScanLines(void)
 
 int GLinitialize() 
 {
+printf("\tseting viewport\n");
  glViewport(rRatioRect.left,                           // init viewport by ratio rect
             iResY-(rRatioRect.top+rRatioRect.bottom),
             rRatioRect.right, 
@@ -454,18 +462,21 @@ int GLinitialize()
  glScissor(0, 0, iResX, iResY);                        // init clipping (fullscreen)
  glEnable(GL_SCISSOR_TEST);                       
 
+ printf("\townscale\n");
 #ifndef OWNSCALE
  glMatrixMode(GL_TEXTURE);                             // init psx tex sow and tow if not "ownscale"
  glLoadIdentity();
  glScalef(1.0f/255.99f,1.0f/255.99f,1.0f);             // geforce precision hack
 #endif 
 
+printf("\tmatrix mode\n");
  glMatrixMode(GL_PROJECTION);                          // init projection with psx resolution
  glLoadIdentity();
  glOrthof(0,PSXDisplay.DisplayMode.x,
          PSXDisplay.DisplayMode.y, 0, -1, 1);
 
 
+		 printf("\tzBuffer\n");
  if(iZBufferDepth)                                     // zbuffer?
   {
    uiBufferBits=GL_COLOR_BUFFER_BIT|GL_DEPTH_BUFFER_BIT;
@@ -478,7 +489,7 @@ int GLinitialize()
    uiBufferBits=GL_COLOR_BUFFER_BIT;
    glDisable(GL_DEPTH_TEST);
   }
-
+printf("\tClear\n");
  glClearColor(0.0f, 0.0f, 0.0f, 0.0f);                 // first buffer clear
  glClear(uiBufferBits);
 // to review !
@@ -496,9 +507,12 @@ int GLinitialize()
   }*/
 
 // MakeDisplayLists();                                   // lists for menu/opaque
+printf("\tGetExtInfos\n");
  GetExtInfos();                                        // get ext infos
+ printf("\tSetExtGLFuncs\n");
  SetExtGLFuncs();                                      // init all kind of stuff (tex function pointers)
  
+ printf("\tglEnable\n");
  glEnable(GL_ALPHA_TEST);                              // wanna alpha test
 
  /*if(!bUseAntiAlias)                                    // no anti-alias (default)
@@ -526,8 +540,10 @@ int GLinitialize()
  bTexEnabled=FALSE;
  bUsingTWin=FALSE;
       
- if(bDrawDither)  glEnable(GL_DITHER);                 // dither mode
- else             glDisable(GL_DITHER); 
+ //if(bDrawDither)  glEnable(GL_DITHER);                 // dither mode
+// else             
+printf("\tGl disabling\n");
+glDisable(GL_DITHER); 
 
  glDisable(GL_FOG);                                    // turn all (currently) unused modes off
  glDisable(GL_LIGHTING);  
@@ -549,10 +565,6 @@ int GLinitialize()
  glPixelTransferi(GL_ALPHA_SCALE, 1);
  glPixelTransferi(GL_ALPHA_BIAS, 0);   */                                               
 
- printf((const char*)glGetString(GL_VENDOR));                       // linux: tell user what is getting used
- printf("\n");
- printf((const char*)glGetString(GL_RENDERER));
- printf("\n");
 
  glFlush();                                            // we are done...
  glFinish();                           
