@@ -3,4 +3,7 @@
 extern int iSoundMuted;
 extern int linesInterlace_user;
 
+extern bool accel_move;
+extern int sens,y_def;
 void hildon_init(int *argc, char ***argv,char *fl,char* lst,bool fullscreen);
+static void *read_accelerometer(void*);
